/****************************************************************************
** $Id: qwerty.h,v 1.5 1997/06/06 10:26:04 eiriken Exp $
**
** QWERTY - little more than a typewriter
**
*****************************************************************************/

#ifndef QWERTY_H
#define QWERTY_H

#include <qwidget.h>
#include <qmenubar.h>
#include <qmlined.h>
#include <qprinter.h>

class Editor : public QWidget
{
    Q_OBJECT
public:
    Editor( QWidget *parent=0, const char *name=0 );
   ~Editor();

public slots:
    void newDoc();
    void load();
    void load( const char *fileName );
    void save();
    void print();
    void closeDoc();

protected:
    void resizeEvent( QResizeEvent * );
    void closeEvent( QCloseEvent * );

private:
    QMenuBar 	   *m;
    QMultiLineEdit *e;
    QPrinter        printer;
};

#endif // QWERTY_H
